"Collection of generic-purpose and stand-alone functions"

__version__ = "0.3.0"

from .factors import *
from .logical import *
from .class_utils import *
from .extensions import *
from .indexes import *
from .functools import *
from .numpy import *
from .io import *
